# nolint start
bibentries <- c(
  grimme2018ifo = bibentry(
    "article",
    title = "Das ifo Importklima -- ein erster Fr\u00FChindikator f\u00FCr die Prognose der deutschen Importe",
    author = "Christian Grimme and Robert Lehmann and Marvin N\u00F6ller",
    journal = "ifo Schnelldienst",
    volume = "71",
    number = "12",
    pages = "27--32",
    year = "2018",
    publisher = "ifo Institut -- Leibniz-Institut f\u00FCr Wirtschaftsforschung an der Universit\u00E4t M\u00FCnchen",
  ),
  grimme2021forecasting = bibentry(
    "article",
    title = "Forecasting imports with information from abroad",
    author = "Grimme, Christian and Lehmann, Robert and N\u00F6ller, Marvin",
    journal = "Economic Modelling",
    volume = "98",
    pages = "109--117",
    year = "2021",
    publisher = "Elsevier"
  )
)
# nolint end
